@@ -3,7 +3,7 @@ package Text::Table::More;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-02-20'; # DATE
 our $DIST = 'Text-Table-More'; # DIST
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 use 5.010001;
 use strict;
@@ -559,7 +559,7 @@ Text::Table::More - Generate text table with simple interface and many options
 
 =head1 VERSION
 
-This document describes version 0.009 of Text::Table::More (from Perl distribution Text-Table-More), released on 2021-02-20.
+This document describes version 0.010 of Text::Table::More (from Perl distribution Text-Table-More), released on 2021-02-20.
 
 =head1 SYNOPSIS
 
@@ -679,26 +679,11 @@ If you set the C<border_style> argument to C<"UTF8::SingleLineBoldHeader">:
      ...
  );
 
-then the output will be something like this:
-
- ââââââââ³âââââââââââââââââââââââââââââââ³âââââââââââââââââââââââ³âââââââââââââââââââââââââââââââ³ââââââââââââââââââââââââââââââââââââââââââââââ³ââââââââââââââââââââââââââ³âââââââââââââââââââââââââââââââââââââââââââââââââ³âââââââââââââââââââââââââââââââââââââââââ
- â Year â            Comedy            â        Drama         â           Variety            â              Lead Comedy Actor              â    Lead Drama Actor     â              Lead Comedy Actress               â           Lead Drama Actress           â
- â¡ââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââ»âââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââ»âââââââââââââââââââââââââââââââââââââââââ©
- â 1962 â The Bob Newhart Show (NBC)   â                      â The Garry Moore Show (CBS)   â E. G. Marshall, The Defenders (CBS)                                   â Shirley Booth, Hazel (NBC)                                                              â
- ââââââââ¼âââââââââââââââââââââââââââââââ¤                      ââââââââââââââââââââââââââââââââ¤                                                                       â                                                                                         â
- â 1963 â The Dick Van Dyke Show (CBS) â The Defenders (CBS)  â The Andy Williams Show (NBC) â                                                                       â                                                                                         â
- ââââââââ¤                              â                      ââââââââââââââââââââââââââââââââ¼ââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââ¼ââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââ¤
- â 1964 â                              â                      â The Danny Kaye Show (CBS)    â Dick Van Dyke, The Dick Van Dyke Show (CBS)                           â Mary Tyler Moore, The Dick Van Dyke Show (CBS)                                          â
- ââââââââ¼âââââââââââââââââââââââââââââââ´âââââââââââââââââââââââ´âââââââââââââââââââââââââââââââ¼ââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââ´ââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââââ¤
- â 1965 â four winners (Outstanding Program Achievements in Entertainment)                   â five winners (Outstanding Program Achievements in Entertainment)                                                                                                â
- ââââââââ¼âââââââââââââââââââââââââââââââ¬âââââââââââââââââââââââ¬âââââââââââââââââââââââââââââââ¼ââââââââââââââââââââââââââââââââââââââââââââââ¬ââââââââââââââââââââââââââ¬âââââââââââââââââââââââââââââââââââââââââââââââââ¬âââââââââââââââââââââââââââââââââââââââââ¤
- â 1966 â The Dick Van Dyke Show (CBS) â The Fugitive (ABC)   â The Andy Williams Show (NBC) â Dick Van Dyke, The Dick Van Dyke Show (CBS) â Bill Cosby, I Spy (CBS) â Mary Tyler Moore, The Dick Van Dyke Show (CBS) â Barbara Stanwyck, The Big Valley (CBS) â
- ââââââââ´âââââââââââââââââââââââââââââââ´âââââââââââââââââââââââ´âââââââââââââââââââââââââââââââ´ââââââââââââââââââââââââââââââââââââââââââââââ´ââââââââââââââââââââââââââ´âââââââââââââââââââââââââââââââââââââââââââââââââ´âââââââââââââââââââââââââââââââââââââââââ
-
 =head1 DESCRIPTION
 
-This module is like L<Text::Table::Tiny> (0.04) with added support for
-column/row spans, and border style.
+This module uses the simple interface like L<Text::Table::Tiny> (0.04) with
+support for more formatting options, most notably column/row spans, border
+style, per-row/column/cell align/valign, and so on.
 
 =for Pod::Coverage ^(.+)$
 
@@ -870,6 +855,12 @@ feature.
 
 =head1 SEE ALSO
 
+L<Text::ANSITable> also offers lots of formatting options, but currently lacks
+support for rowspan/colspan. It also uses an OO interface and has features I
+never use: hiding rows and selecting display columns different from declared
+columns. I currently plan to actively develop Text::Table::More instead of
+Text::ANSITable, but we'll see.
+
 L<Acme::CPANModules::TextTable> contains a comparison and benchmark for modules
 that generate text table.
 
